==> bitbarconnector-0.1.tar.gz: bitbarconnector-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'bitbarconnector',         # How you named your package folder (MyLib)
  packages = ['bitbarconnector'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This library helps you connect with bitbar apis and run andriod instrument tests',   # Give a short description about your library
  author = 'Tajinder Singh',                   # Type in your name
  author_email = 'tajinder.singh1985@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/singh-tajinder/bitbarconnector',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/singh-tajinder/bitbarconnector/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['bitbar', 'andriod testing', 'bitbar apis'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'testdroid',
          'configparser',
          'argparse'
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.8',
  ],
)

==> bitbarconnector-0.1.2.tar.gz: bitbarconnector-0.1.2/setup.py <==
from distutils.core import setup
setup(
  name = 'bitbarconnector',         # How you named your package folder (MyLib)
  packages = ['bitbarconnector'],   # Chose the same as "name"
  version = '0.1.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This library helps you connect with bitbar apis and run andriod instrument tests',   # Give a short description about your library
  author = 'Tajinder Singh',                   # Type in your name
  author_email = 'tajinder.singh1985@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/singh-tajinder/bitbarconnector',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/singh-tajinder/bitbarconnector/archive/v_01.02.tar.gz',    # I explain this later on
  keywords = ['bitbar', 'andriod testing', 'bitbar apis'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'testdroid',
          'configparser',
          'argparse'
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.8',
  ],
)
